LICENSES = {
    "AAL": "AAL",
    "AFL-1.2": "AFL-1.2",
    "AFL-2.0": "AFL-2.0",
    "AFL-2.1": "AFL-2.1",
    "AFL-3.0": "AFL-3.0",
    "AGPL-3.0": "AGPL-3.0",
    "ANTLR-PD": "ANTLR-PD",
    "APL-1.0": "APL-1.0",
    "APL2": "Apache-2.0",
    "APSL-1.0": "APSL-1.0",
    "APSL-1.1": "APSL-1.1",
    "APSL-1.2": "APSL-1.2",
    "APSL-2.0": "APSL-2.0",
    "ASL": "Apache-2.0",
    "Adobe": "Adobe",
    "Apache": "Apache-2.0",
    "Apache 2.0": "Apache-2.0",
    "Apache License 2.0": "Apache-2.0",
    "Apache License, Version 2.0": "Apache-2.0",
    "Apache Software License": "Apache-2.0",
    "Apache-1.0": "Apache-1.0",
    "Apache-1.1": "Apache-1.1",
    "Apache-2.0": "Apache-2.0",
    "Artistic-1.0": "Artistic-1.0",
    "Artistic-2.0": "Artistic-2.0",
    "BSD": "BSD",
    "BSD - See ndg/httpsclient/LICENCE file for details": "BSD",
    "BSD 3-Clause": "BSD-3-Clause",
    "BSD 3-Clause License": "BSD-3-Clause",
    "BSD License": "BSD",
    "BSD or Apache License, Version 2.0": "BSD",
    "BSD, Public Domain": "BSD",
    "BSD-2-Clause": "BSD-2-Clause",
    "BSD-3-Clause": "BSD-3-Clause",
    "BSD-4-Clause": "BSD-4-Clause",
    "BSD-derived (http://www.repoze.org/LICENSE.txt)": "BSD",
    "BSD-like": "BSD",
    "BSL-1.0": "BSL-1.0",
    "BitstreamVera": "BitstreamVera",
    "CATOSL-1.1": "CATOSL-1.1",
    "CC-BY-1.0": "CC-BY-1.0",
    "CC-BY-2.0": "CC-BY-2.0",
    "CC-BY-2.5": "CC-BY-2.5",
    "CC-BY-3.0": "CC-BY-3.0",
    "CC-BY-NC-1.0": "CC-BY-NC-1.0",
    "CC-BY-NC-2.0": "CC-BY-NC-2.0",
    "CC-BY-NC-2.5": "CC-BY-NC-2.5",
    "CC-BY-NC-3.0": "CC-BY-NC-3.0",
    "CC-BY-NC-ND-1.0": "CC-BY-NC-ND-1.0",
    "CC-BY-NC-ND-2.0": "CC-BY-NC-ND-2.0",
    "CC-BY-NC-ND-2.5": "CC-BY-NC-ND-2.5",
    "CC-BY-NC-ND-3.0": "CC-BY-NC-ND-3.0",
    "CC-BY-NC-SA-1.0": "CC-BY-NC-SA-1.0",
    "CC-BY-NC-SA-2.0": "CC-BY-NC-SA-2.0",
    "CC-BY-NC-SA-2.5": "CC-BY-NC-SA-2.5",
    "CC-BY-NC-SA-3.0": "CC-BY-NC-SA-3.0",
    "CC-BY-ND-1.0": "CC-BY-ND-1.0",
    "CC-BY-ND-2.0": "CC-BY-ND-2.0",
    "CC-BY-ND-2.5": "CC-BY-ND-2.5",
    "CC-BY-ND-3.0": "CC-BY-ND-3.0",
    "CC-BY-SA-1.0": "CC-BY-SA-1.0",
    "CC-BY-SA-2.0": "CC-BY-SA-2.0",
    "CC-BY-SA-2.5": "CC-BY-SA-2.5",
    "CC-BY-SA-3.0": "CC-BY-SA-3.0",
    "CC0-1.0": "CC0-1.0",
    "CDDL-1.0": "CDDL-1.0",
    "CECILL-1.0": "CECILL-1.0",
    "CECILL-2.0": "CECILL-2.0",
    "CECILL-B": "CECILL-B",
    "CECILL-C": "CECILL-C",
    "CPAL-1.0": "CPAL-1.0",
    "CPL-1.0": "CPL-1.0",
    "CUA-OPL-1.0": "CUA-OPL-1.0",
    "ClArtistic": "ClArtistic",
    "DSSSL": "DSSSL",
    "Dual License": "BSD",
    "ECL-1.0": "ECL-1.0",
    "ECL-2.0": "ECL-2.0",
    "EDL-1.0": "EDL-1.0",
    "EFL-1.0": "EFL-1.0",
    "EFL-2.0": "EFL-2.0",
    "EPL-1.0": "EPL-1.0",
    "EPL-2.0": "EPL-2.0",
    "EUDatagrid": "EUDatagrid",
    "EUPL-1.0": "EUPL-1.0",
    "EUPL-1.1": "EUPL-1.1",
    "Elfutils-Exception": "Elfutils-Exception",
    "Entessa": "Entessa",
    "ErlPL-1.1": "ErlPL-1.1",
    "Expat license": "MIT",
    "Expat (MIT/X11)": "MIT",
    "Fair": "Fair",
    "Frameworx-1.0": "Frameworx-1.0",
    "FreeType": "FreeType",
    "GFDL-1.1": "GFDL-1.1",
    "GFDL-1.2": "GFDL-1.2",
    "GFDL-1.3": "GFDL-1.3",
    "GNU GPLv3+": "GPL-3.0",
    "GNU General Public License Version 3": "GPL-3.0",
    "GNU LGPL": "LGPL-2.0",
    "GPL": "GPL-1.0",
    "GPL V2 or later": "GPL-2.0",
    "GPL-1.0": "GPL-1.0",
    "GPL-2-with-bison-exception": "GPL-2-with-bison-exception",
    "GPL-2.0": "GPL-2.0",
    "GPL-2.0-with-GCC-exception": "GPL-2.0-with-GCC-exception",
    "GPL-2.0-with-autoconf-exception": "GPL-2.0-with-autoconf-exception",
    "GPL-2.0-with-classpath-exception": "GPL-2.0-with-classpath-exception",
    "GPL-2.0-with-font-exception": "GPL-2.0-with-font-exception",
    "GPL-3.0": "GPL-3.0",
    "GPL-3.0-with-GCC-exception": "GPL-3.0-with-GCC-exception",
    "GPL-3.0-with-autoconf-exception": "GPL-3.0-with-autoconf-exception",
    "GPLv3+": "GPLv3",
    "HPND": "HPND",
    "IPA": "IPA",
    "IPL-1.0": "IPL-1.0",
    "ISC": "ISC",
    "ISC license": "ISC",
    "LGPL": "LGPL-2.0",
    "LGPL-2.0": "LGPL-2.0",
    "LGPL-2.1": "LGPL-2.1",
    "LGPL-3.0": "LGPL-3.0",
    "LGPLv2": "LGPL-2.0",
    "LGPLv2+": "LGPL-2.0",
    "LGPLv3": "LGPL-3.0",
    "LPGL, see LICENSE file.": "LGPL-1.0",
    "LPL-1.02": "LPL-1.02",
    "LPPL-1.0": "LPPL-1.0",
    "LPPL-1.1": "LPPL-1.1",
    "LPPL-1.2": "LPPL-1.2",
    "LPPL-1.3c": "LPPL-1.3c",
    "Libpng": "Libpng",
    "License :: OSI Approved :: Apache Software License": "Apache-2.0",
    "License :: OSI Approved :: MIT License (http://opensource.org/licenses/MIT)": "MIT",
    "MIT": "MIT",
    "MIT License": "MIT",
    "MIT license": "MIT",
    "MIT/X11": "MIT",
    "MPL v2": "MPL-2.0",
    "MPL-1.0": "MPL-1.0",
    "MPL-1.1": "MPL-1.1",
    "MPL-2.0": "MPL-2.0",
    "MPLv2.0, MIT Licences": "MIT",
    "MS-PL": "MS-PL",
    "MS-RL": "MS-RL",
    "MirOS": "MirOS",
    "Modified BSD License": "BSD",
    "Motosoto": "Motosoto",
    "Multics": "Multics",
    "NASA-1.3": "NASA-1.3",
    "NCSA": "NCSA",
    "NGPL": "NGPL",
    "NPOSL-3.0": "NPOSL-3.0",
    "NTP": "NTP",
    "Nauman": "Nauman",
    "New BSD": "BSD",
    "Nokia": "Nokia",
    "OASIS": "OASIS",
    "OCLC-2.0": "OCLC-2.0",
    "ODbL-1.0": "ODbL-1.0",
    "OFL-1.1": "OFL-1.1",
    "OGTSL": "OGTSL",
    "OLDAP-2.8": "OLDAP-2.8",
    "OSL-1.0": "OSL-1.0",
    "OSL-2.0": "OSL-2.0",
    "OSL-3.0": "OSL-3.0",
    "OpenSSL": "OpenSSL",
    "PD": "PD",
    "PHP-3.0": "PHP-3.0",
    "PSF": "Python-2.0",
    "PSF License": "Python-2.0",
    "PSF license": "Python-2.0",
    "PSFL": "Python-2.0",
    "PostgreSQL": "PostgreSQL",
    "Proprietary": "Proprietary",
    "Public Domain": "PD",
    "Public domain": "PD",
    "Python Software Foundation License": "Python-2.0",
    "Python style": "Python-2.0",
    "Python-2.0": "Python-2.0",
    "QPL-1.0": "QPL-1.0",
    "RHeCos-1": "RHeCos-1",
    "RHeCos-1.1": "RHeCos-1.1",
    "RPL-1.5": "RPL-1.5",
    "RPSL-1.0": "RPSL-1.0",
    "RSCPL": "RSCPL",
    "Ruby": "Ruby",
    "SAX-PD": "SAX-PD",
    "SGI-1": "SGI-1",
    "SPL-1.0": "SPL-1.0",
    "Simple-2.0": "Simple-2.0",
    "Sleepycat": "Sleepycat",
    "SugarCRM-1": "SugarCRM-1",
    "SugarCRM-1.1.3": "SugarCRM-1.1.3",
    "This software released into the public domain. Anyone is free to copy,": "PD",
    "Two-clause BSD license": "BSD-2-Clause",
    "UCB": "UCB",
    "UNKNOWN": "CLOSED",
    "VSL-1.0": "VSL-1.0",
    "W3C": "W3C",
    "WXwindows": "WXwindows",
    "Watcom-1.0": "Watcom-1.0",
    "XFree86-1.0": "XFree86-1.0",
    "XFree86-1.1": "XFree86-1.1",
    "XSL": "XSL",
    "Xnet": "Xnet",
    "YPL-1.1": "YPL-1.1",
    "ZPL 2.1": "ZPL-2.0",
    "ZPL-1.1": "ZPL-1.1",
    "ZPL-2.0": "ZPL-2.0",
    "ZPL-2.1": "ZPL-2.1",
    "Zimbra-1.3": "Zimbra-1.3",
    "Zlib": "Zlib",
    "eCos-2.0": "eCos-2.0",
    "gSOAP-1": "gSOAP-1",
    "gSOAP-1.3b": "gSOAP-1.3b",
    "http://creativecommons.org/publicdomain/zero/1.0/": "PD",
    "http://opensource.org/licenses/MIT": "MIT",
    "public domain, Python, 2-Clause BSD, GPL 3 (see COPYING.txt)": "PD",
}

